@@ -59,19 +59,25 @@ def scrape_comments(reddit, post_ids: List[str], num_comments: int) -> List[Dict
     comments_data = []
 
     for post_id in tqdm(post_ids, desc="Posts"):
-        post = reddit.submission(id=post_id)
+        try:
+            post = reddit.submission(id=post_id)
 
-        post.comments.replace_more(limit=None)
-        for comment in tqdm(post.comments.list()[:num_comments], total=num_comments, desc="Comments"):
-            comment_data = {
-                "post_title": post.title,
-                "post_id": post_id,
-                "commenter_name": comment.author.name,
-                "comment_body": comment.body,
-                "num_upvotes": comment.score,
-                "comment_sentiment": analyze_sentiment(comment.body),
-            }
-            comments_data.append(comment_data)
+            post.comments.replace_more(limit=None)
+            for comment in tqdm(post.comments.list()[:num_comments], total=num_comments, desc="Comments"):
+                try:
+                    comment_data = {
+                        "post_title": post.title,
+                        "post_id": post_id,
+                        "commenter_name": comment.author.name,
+                        "comment_body": comment.body,
+                        "num_upvotes": comment.score,
+                        "comment_sentiment": analyze_sentiment(comment.body),
+                    }
+                    comments_data.append(comment_data)
+                except Exception as e:
+                    print(f"Error processing comment {comment.id}: {e}")
+        except Exception as e:
+            print(f"Error processing post {post_id}: {e}")
 
     return comments_data
 
